@@ -8,7 +8,7 @@ import psycopg2.extensions
 import psycopg2.extras
 import singer
 import singer.schema
-from c8connector import C8Connector, ConfigProperty
+from c8connector import C8Connector, ConfigProperty, Sample
 from singer import utils, metadata, get_bookmark
 from singer.catalog import Catalog
 
@@ -18,9 +18,10 @@ from c8_source_postgres.discovery_utils import discover_db
 from c8_source_postgres.stream_utils import (
     dump_catalog, clear_state_on_replication_change,
     is_selected_via_metadata, refresh_streams_schema, any_logical_streams)
-from c8_source_postgres.sync_strategies import full_table
+from c8_source_postgres.sync_strategies import full_table, sample_data
 from c8_source_postgres.sync_strategies import incremental
 from c8_source_postgres.sync_strategies import logical_replication
+from c8_source_postgres.sync_strategies.sample_data import fetch_samples
 
 LOGGER = singer.get_logger('c8_source_postgres')
 
@@ -467,13 +468,54 @@ class PostgresSourceConnector(C8Connector):
         """Returns the description of the connector."""
         return "GDN data connector source for Postgres"
 
-    def validate(self, integration: dict) -> bool:
-        """Validate given configurations against the connector."""
-        return True
+    def validate(self, integration: dict) -> None:
+        """Validate given configurations against the connector.
+        If invalid, throw an exception with the cause.
+        """
+        config = {
+            # Required config keys
+            'host': integration['host'],
+            'user': integration['user'],
+            'password': integration['password'],
+            'port': integration['port'],
+            'dbname': integration['dbname'],
+            # Optional config keys
+            'tap_id': integration.get('tap_id'),
+            'filter_schemas': integration.get('filter_schemas'),
+            'debug_lsn': integration.get('debug_lsn') == 'true',
+            'max_run_seconds': integration.get('max_run_seconds', 43200),
+            'break_at_end_lsn': integration.get('break_at_end_lsn', True),
+            'logical_poll_total_seconds': float(integration.get('logical_poll_total_seconds', 0)),
+            'use_secondary': integration.get('use_secondary', False),
+        }
+        do_discovery(config)
 
-    def samples(self, integration: dict) -> list:
+    def samples(self, integration: dict) -> list[Sample]:
         """Fetch sample data using the provided configurations."""
-        return []
+        config = {
+            # Required config keys
+            'host': integration['host'],
+            'user': integration['user'],
+            'password': integration['password'],
+            'port': integration['port'],
+            'dbname': integration['dbname'],
+            # Optional config keys
+            'tap_id': integration.get('tap_id'),
+            'filter_schemas': integration.get('filter_schemas'),
+            'debug_lsn': integration.get('debug_lsn') == 'true',
+            'max_run_seconds': integration.get('max_run_seconds', 43200),
+            'break_at_end_lsn': integration.get('break_at_end_lsn', True),
+            'logical_poll_total_seconds': float(integration.get('logical_poll_total_seconds', 0)),
+            'use_secondary': integration.get('use_secondary', False),
+        }
+        streams = do_discovery(config)
+        results = []
+        for stream in streams:
+            results.append(Sample(
+                stream=stream,
+                data=fetch_samples(config, stream))
+            )
+        return results
 
     def config(self) -> list[ConfigProperty]:
         """Get configuration parameters for the connector."""
